@@ -1,13 +1,14 @@
 package Data::Sah::Compiler::human;
 
-our $DATE = '2015-02-21'; # DATE
-our $VERSION = '0.46'; # VERSION
+our $DATE = '2015-03-24'; # DATE
+our $VERSION = '0.47'; # VERSION
 
 use 5.010;
 use strict;
 use warnings;
 #use Log::Any qw($log);
 
+use Data::Dmp qw(dmp);
 use Mo qw(build default);
 use POSIX qw(locale_h);
 use Text::sprintfn;
@@ -67,24 +68,7 @@ sub literal {
     my ($self, $val) = @_;
 
     return $val unless ref($val);
-
-    # for now we use JSON. btw, JSON does obey locale setting, e.g. [1.2]
-    # encoded to "[1,2]" in id_ID.
-    state $json = do {
-        require JSON;
-        JSON->new->allow_nonref;
-    };
-
-    # we also need cleaning if we use json, since json can't handle qr//, for
-    # one.
-    state $cleanser = do {
-        require Data::Clean::JSON;
-        Data::Clean::JSON->get_cleanser;
-    };
-
-    # XXX for nicer output, perhaps say "empty array" instead of "[]", "empty
-    # hash" instead of "{}", etc.
-    $json->encode($cleanser->clone_and_clean($val));
+    dmp($val);
 }
 
 # translate
@@ -519,7 +503,7 @@ Data::Sah::Compiler::human - Compile Sah schema to human language
 
 =head1 VERSION
 
-This document describes version 0.46 of Data::Sah::Compiler::human (from Perl distribution Data-Sah), released on 2015-02-21.
+This document describes version 0.47 of Data::Sah::Compiler::human (from Perl distribution Data-Sah), released on 2015-03-24.
 
 =head1 SYNOPSIS
 
@@ -588,7 +572,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Data-Sah>.
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/sharyanto/perl-Data-Sah>.
+Source repository is at L<https://github.com/perlancar/perl-Data-Sah>.
 
 =head1 BUGS
 
